<?php
/**
 * latest_post Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add latest_post section
$wp_customize->add_section( 'house_state_pro_latest_post_section', array(
	'title'             => esc_html__( 'Latest Post','house-state-pro' ),
	'description'       => esc_html__( 'Latest Post Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
) );

// latest_post content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[latest_post_section_enable]', array(
	'default'			=> 	$options['latest_post_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[latest_post_section_enable]', array(
	'label'             => esc_html__( 'latest_post Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_latest_post_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );


// latest_post content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[latest_post_content_type]', array(
	'default'          	=> $options['latest_post_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[latest_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_latest_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_latest_post_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'house-state-pro' ),
            'post' 		=> esc_html__( 'Post', 'house-state-pro' ),
            'category' 	=> esc_html__( 'Category', 'house-state-pro' ),
	),
) );


for ( $i = 1; $i <= 5; $i++ ) :

	// latest_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[latest_post_content_page_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[latest_post_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_latest_post_section',
		'choices'			=> house_state_pro_page_choices(),
		'active_callback'	=> 'house_state_pro_is_latest_post_section_content_page_enable',
	) ) );

	// latest_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[latest_post_content_post_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[latest_post_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_latest_post_section',
		'choices'			=> house_state_pro_post_choices(),
		'active_callback'	=> 'house_state_pro_is_latest_post_section_content_post_enable',
	) ) );

endfor;

// latest_post posts drop down chooser control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[latest_post_category]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_single_category',
) );

$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'house_state_pro_theme_options[latest_post_category]', array(
	'label'             => esc_html__( 'Select Categories', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'house-state-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'house_state_pro_latest_post_section',
	'active_callback'	=> 'house_state_pro_is_latest_post_section_content_category_enable',
) ) ); 


