<?php
/**
 * Recent Products Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add popular_products section
$wp_customize->add_section( 'house_state_pro_popular_products_section', array(
    'title'             => esc_html__( 'Popular Product','house-state-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'house-state-pro' ),
    'panel'             => 'house_state_pro_front_page_panel',
) );

// popular_products content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[popular_products_section_enable]', array(
    'default'           =>  $options['popular_products_section_enable'],
    'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[popular_products_section_enable]', array(
    'label'             => esc_html__( 'Recent product Section Enable', 'house-state-pro' ),
    'section'           => 'house_state_pro_popular_products_section',
    'on_off_label'      => house_state_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[popular_products_section_enable]', array(
        'selector'            => '#recent-products .wrapper',
        'settings'            => 'house_state_pro_theme_options[popular_products_section_enable]',
    ) );
}

// popular_products title setting and control
$wp_customize->add_setting( 'house_state_pro_theme_options[popular_products_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[popular_products_title]', array(
    'label'             => esc_html__( 'Title', 'house-state-pro' ),
    'section'           => 'house_state_pro_popular_products_section',
    'active_callback'   => 'house_state_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[popular_products_title]', array(
        'selector'            => '#recent-products h2.section-title',
        'settings'            => 'house_state_pro_theme_options[popular_products_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'house_state_pro_popular_products_title_partial',
    ) );
}


$wp_customize->add_setting( 'house_state_pro_theme_options[popular_products_count]', array(
    'default'           => $options['popular_products_count'],
    'sanitize_callback' => 'house_state_pro_sanitize_number_range',
    'validate_callback' => 'house_state_pro_validate_popular_products_count',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[popular_products_count]', array(
    'label'             => esc_html__( 'Number of Product', 'house-state-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
    'section'           => 'house_state_pro_popular_products_section',
    'active_callback'   => 'house_state_pro_is_popular_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 15,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'house_state_pro_theme_options[popular_products_content_type]', array(
    'default'           => $options['popular_products_content_type'],
    'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[popular_products_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
    'section'           => 'house_state_pro_popular_products_section',
    'type'              => 'select',
    'active_callback'   => 'house_state_pro_is_popular_products_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'house-state-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'house-state-pro' ),
        ),
) );

for( $i = 1 ; $i <= $options['popular_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'house_state_pro_theme_options[popular_products_content_page_' . $i . ']', array(
        'sanitize_callback' => 'house_state_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[popular_products_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'house-state-pro' ), $i ),
        'section'           => 'house_state_pro_popular_products_section',
        'choices'           => house_state_pro_product_choices(),
        'active_callback'   => 'house_state_pro_is_popular_products_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'house_state_pro_theme_options[popular_products_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize,'house_state_pro_theme_options[popular_products_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'house-state-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'house-state-pro' ),
    'section'           => 'house_state_pro_popular_products_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'house_state_pro_is_popular_products_section_content_product_category_enable',
) ) );