<?php
/**
 * team Section options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

// Add team section
$wp_customize->add_section( 'house_state_pro_team_section', array(
	'title'             => esc_html__( 'Team','house-state-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'house-state-pro' ),
	'panel'             => 'house_state_pro_front_page_panel',
) );



// team content enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'team Section Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );

// team autoplay enable control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[team_autoplay_enable]', array(
	'default'			=> 	$options['team_autoplay_enable'],
	'sanitize_callback' => 'house_state_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new House_State_Pro_Switch_Control( $wp_customize, 'house_state_pro_theme_options[team_autoplay_enable]', array(
	'label'             => esc_html__( 'team Autoplay Enable', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	'active_callback'   => 'house_state_pro_is_team_section_enable',
	'on_off_label' 		=> house_state_pro_switch_options(),
) ) );



$wp_customize->add_setting( 'house_state_pro_theme_options[team_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_section_title'],
	'transport'			=>'refresh'
) );

$wp_customize->add_control('house_state_pro_theme_options[team_section_title]', array(
	'label'             =>  esc_html__( 'Section Title', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	'type'              => 'text',
	'active_callback'	=> 'house_state_pro_is_team_section_enable',
));

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'house_state_pro_theme_options[team_section_title]', array(
		'selector'            => '#team-section .section-header .section-title',
		'settings'            => 'house_state_pro_theme_options[team_section_title]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'house_state_pro_team_title_txt_partial',
    ) );
}


// team number control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
	'validate_callback' => 'house_state_pro_validate_team_count',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 15. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	'active_callback'   => 'house_state_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 15,
		'style' => 'width: 100px;'
		),
) );

// team content type control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'house_state_pro_sanitize_select',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'house_state_pro_is_team_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'house-state-pro' ),
            'post' 		=> esc_html__( 'Post', 'house-state-pro' ),
            'category' 	=> esc_html__( 'Category', 'house-state-pro' ),
	),
) );


for ( $i = 1; $i <= $options['team_count']; $i++ ) :


	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[team_content_page_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[team_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_team_section',
		'choices'			=> house_state_pro_page_choices(),
		'active_callback'	=> 'house_state_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'house_state_pro_theme_options[team_content_post_'. $i .']', array(
		'sanitize_callback' => 'house_state_pro_sanitize_page',
	) );

	$wp_customize->add_control( new House_State_Pro_Dropdown_Chooser( $wp_customize, 'house_state_pro_theme_options[team_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'house-state-pro'), $i ),
		'section'           => 'house_state_pro_team_section',
		'choices'			=> house_state_pro_post_choices(),
		'active_callback'	=> 'house_state_pro_is_team_section_content_post_enable',
	) ) );

	// team social
	$wp_customize->add_setting( 'house_state_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new House_State_Pro_Multi_Input_Custom_Control( $wp_customize, 'house_state_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'house-state-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'house-state-pro' ),
		'section'           => 'house_state_pro_team_section',
		'active_callback' 	=> 'house_state_pro_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new House_State_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'house_state_pro_team_section',
			'active_callback' => 'house_state_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// team posts drop down chooser control and setting
$wp_customize->add_setting( 'house_state_pro_theme_options[team_category]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_single_category',
) );

$wp_customize->add_control( new House_State_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'house_state_pro_theme_options[team_category]', array(
	'label'             => esc_html__( 'Select Categories', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'house-state-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'house_state_pro_team_section',
	'active_callback'	=> 'house_state_pro_is_team_section_content_category_enable',
) ) ); 



//style

$wp_customize->add_setting( 'house_state_pro_theme_options[style_team_overlay_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'

	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'house_state_pro_theme_options[style_team_overlay_color]', array(
	'label'             => esc_html__( 'Overlay Color', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_team_overlay_value]', array(
	'default'          	=> 3,
	'sanitize_callback' => 'house_state_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'house_state_pro_theme_options[style_team_overlay_value]', array(
	'label'             => esc_html__( 'Overlay Value', 'house-state-pro' ),
	'description'       => esc_html__( 'Note: Min 0 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 0,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_team_background]', array(
	'sanitize_callback' => 'house_state_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'house_state_pro_theme_options[style_team_background]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'house-state-pro' ),
		'section'     		=> 'house_state_pro_team_section',
) ) );

$wp_customize->add_setting( 'house_state_pro_theme_options[style_team_background_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'house_state_pro_theme_options[style_team_background_color]', array(
	'label'             => esc_html__( 'Background Color', 'house-state-pro' ),
	'section'           => 'house_state_pro_team_section',
	) ) );
