<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function house_state_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'house-state-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function house_state_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'house-state-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function house_state_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'house-state-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function house_state_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'house-state-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function house_state_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'house-state-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'house_state_pro_typography_options' ) ) :
       function house_state_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'house-state-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'house_state_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function house_state_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'house-state-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'house-state-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'house-state-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'house-state-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'house-state-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'house-state-pro' ),
        );

        $output = apply_filters( 'house_state_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function house_state_pro_site_layout() {
        $house_state_pro_site_layout = array(
            'wide'          => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout'  => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout'  => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'house_state_pro_site_layout', $house_state_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'house_state_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function house_state_pro_selected_sidebar() {
        $house_state_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'house-state-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'house-state-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'house-state-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'house-state-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'house-state-pro' ),
        );

        $output = apply_filters( 'house_state_pro_selected_sidebar', $house_state_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function house_state_pro_global_sidebar_position() {
        $house_state_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'house_state_pro_global_sidebar_position', $house_state_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function house_state_pro_sidebar_position() {
        $house_state_pro_sidebar_position = array(
            'right-sidebar'         => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'          => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'            => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'    => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'house_state_pro_sidebar_position', $house_state_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'house_state_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function house_state_pro_pagination_options() {
        $house_state_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'house-state-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'house-state-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'house-state-pro' ),
        );

        $output = apply_filters( 'house_state_pro_pagination_options', $house_state_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'house_state_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function house_state_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'house-state-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'house-state-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'house-state-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'house-state-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'house-state-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'house-state-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'house-state-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'house-state-pro' ),
        );
        return apply_filters( 'house_state_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'house_state_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function house_state_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'house-state-pro' ),
            'off'       => esc_html__( 'Disable', 'house-state-pro' )
        );
        return apply_filters( 'house_state_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'house_state_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function house_state_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'house-state-pro' ),
            'off'       => esc_html__( 'No', 'house-state-pro' )
        );
        return apply_filters( 'house_state_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'house_state_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function house_state_pro_sortable_sections() {
        $options = house_state_pro_get_theme_options();
        // 'slider,about,project,team,service,blog,partner,counter,course,latest_products,collection,recent_products,featured_products,trending_product,popular_products,latest_post,inner_content,popular_post'
        $sections = array(
            'slider'                => esc_html__( 'Slider', 'house-state-pro' ),
            'about'                 => esc_html__( 'About us', 'house-state-pro' ),
            'project'               => esc_html__( 'Project', 'house-state-pro' ),
            'team'                  => esc_html__( 'Team', 'house-state-pro' ),
            'service'               => esc_html__( 'Service', 'house-state-pro' ),
            'blog'                  => esc_html__( 'Blog', 'house-state-pro' ),
            'partner'               => esc_html__( 'Partner', 'house-state-pro' ),
            'counter'               => esc_html__( 'Counter', 'house-state-pro' ),
            'course'                => esc_html__( 'Course', 'house-state-pro' ),
            'latest_products'       => esc_html__( 'Latest Products', 'house-state-pro' ),
            'collection'            => esc_html__( 'Collection', 'house-state-pro' ),
            'recent_products'       => esc_html__( 'Recent Products', 'house-state-pro' ),
            'featured_products'     => esc_html__( 'Featured Products', 'house-state-pro' ),
            'trending_product'      => esc_html__( 'Trending Product', 'house-state-pro' ),
            'popular_products'      => esc_html__( 'Popular Product', 'house-state-pro' ),
            'latest_post'           => esc_html__( 'Latest Post', 'house-state-pro' ),
            'inner_content'         => esc_html__( 'Inner Content', 'house-state-pro' ),
            'popular_post'          => esc_html__( 'Popular Post', 'house-state-pro' ),
           

        );
       
        return apply_filters( 'house_state_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'house_state_pro_latest_products_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function house_state_pro_latest_products_content_type() {
        $house_state_pro_latest_products_content_type = array(
            'category'  => esc_html__( 'Category', 'house-state-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $house_state_pro_latest_products_content_type = array_merge( $house_state_pro_latest_products_content_type, array(
                'product-category'   => esc_html__( 'Product Category', 'house-state-pro' ),
                ) );
        }

        $output = apply_filters( 'house_state_pro_latest_products_content_type', $house_state_pro_latest_products_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'house_state_pro_package_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function house_state_pro_package_content_type() {
        $house_state_pro_package_content_type = array(
            'page'      => esc_html__( 'Page', 'house-state-pro' ),
            'post'      => esc_html__( 'Post', 'house-state-pro' ),
            'category'  => esc_html__( 'Category', 'house-state-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $house_state_pro_package_content_type = array_merge( $house_state_pro_package_content_type, array(
                'trip'          => esc_html__( 'Trip', 'house-state-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'house-state-pro' ),
                'destination'   => esc_html__( 'Destination', 'house-state-pro' ),
                'activity'      => esc_html__( 'Activity', 'house-state-pro' ),
                ) );
        }

        $output = apply_filters( 'house_state_pro_package_content_type', $house_state_pro_package_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_offer_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function house_state_pro_offer_content_type() {
        $house_state_pro_offer_content_type = array(
            'page'      => esc_html__( 'Page', 'house-state-pro' ),
            'post'      => esc_html__( 'Post', 'house-state-pro' ),
            'category'  => esc_html__( 'Category', 'house-state-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $house_state_pro_offer_content_type = array_merge( $house_state_pro_offer_content_type, array(
                'trip'          => esc_html__( 'Trip', 'house-state-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'house-state-pro' ),
                'destination'   => esc_html__( 'Destination', 'house-state-pro' ),
                'activity'      => esc_html__( 'Activity', 'house-state-pro' ),
                ) );
        }

        $output = apply_filters( 'house_state_pro_offer_content_type', $house_state_pro_offer_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'house_state_pro_recommended_package_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function house_state_pro_recommended_package_content_type() {
        $house_state_pro_recommended_package_content_type = array(
            'page'      => esc_html__( 'Page', 'house-state-pro' ),
            'post'      => esc_html__( 'Post', 'house-state-pro' ),
            'category'  => esc_html__( 'Category', 'house-state-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $house_state_pro_recommended_package_content_type = array_merge( $house_state_pro_recommended_package_content_type, array(
                'trip'          => esc_html__( 'Trip', 'house-state-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'house-state-pro' ),
                'destination'   => esc_html__( 'Destination', 'house-state-pro' ),
                'activity'      => esc_html__( 'Activity', 'house-state-pro' ),
                ) );
        }

        $output = apply_filters( 'house_state_pro_recommended_package_content_type', $house_state_pro_recommended_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'house_state_pro_featured_package_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function house_state_pro_featured_package_content_type() {
        $house_state_pro_featured_package_content_type = array(
            'category'  => esc_html__( 'Category', 'house-state-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $house_state_pro_featured_package_content_type = array_merge( $house_state_pro_featured_package_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'house-state-pro' ),
                'destination'   => esc_html__( 'Destination', 'house-state-pro' ),
                'activity'      => esc_html__( 'Activity', 'house-state-pro' ),
                ) );
        }

        $output = apply_filters( 'house_state_pro_featured_package_content_type', $house_state_pro_featured_package_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_cta_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function house_state_pro_cta_content_type() {
        $house_state_pro_cta_content_type = array(
            'page'      => esc_html__( 'Page', 'house-state-pro' ),
            'post'      => esc_html__( 'Post', 'house-state-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $house_state_pro_cta_content_type = array_merge( $house_state_pro_cta_content_type, array(
                'trip'          => esc_html__( 'Trip', 'house-state-pro' ),
                ) );
        }

        $output = apply_filters( 'house_state_pro_cta_content_type', $house_state_pro_cta_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_featured_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function house_state_pro_featured_product_content_type() {
        $house_state_pro_featured_product_content_type = array(
            'product'   => esc_html__( 'Product', 'house-state-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'house-state-pro' ),
        );

        $output = apply_filters( 'house_state_pro_featured_product_content_type', $house_state_pro_featured_product_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'house_state_pro_recent_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function house_state_pro_recent_product_content_type() {
        $house_state_pro_recent_product_content_type = array(
            'product'   => esc_html__( 'Product', 'house-state-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'house-state-pro' ),
        );

        $output = apply_filters( 'house_state_pro_recent_product_content_type', $house_state_pro_recent_product_content_type );

        return $output;
    }
endif;