<?php
/**
 * Banner section
 *
 * This is the template for the content of partner section
 *
 * @package Theme Palace
 * @subpackage House State Pro
 * @since House State Pro 1.0.0
 */
if ( ! function_exists( 'house_state_pro_add_partner_section' ) ) :
    /**
    * Add partner section
    *
    *@since House State Pro 1.0.0
    */
    function house_state_pro_add_partner_section() {
        $options = house_state_pro_get_theme_options();
        // Check if partner is enabled on frontpage
        $partner_enable = apply_filters( 'house_state_pro_section_status', true, 'partner_section_enable' );

        if ( true !== $partner_enable ) {
            return false;
        }
        // Get partner section details
        $section_details = array();
        $section_details = apply_filters( 'house_state_pro_filter_partner_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render partner section now.
        house_state_pro_render_partner_section( $section_details );
}

endif;

if ( ! function_exists( 'house_state_pro_get_partner_section_details' ) ) :
    /**
    * partner section details.
    *
    * @since House State Pro 1.0.0
    * @param array $input partner section details.
    */
    function house_state_pro_get_partner_section_details( $input ) {
        $options = house_state_pro_get_theme_options();

        // Content type.
        $partner_content_type    = $options['partner_content_type'];
        $partner_count           = ! empty( $options['partner_count'] ) ? $options['partner_count'] : 6;
        
        $content = array();
        switch ( $partner_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    if ( ! empty( $options['partner_content_page_' . $i] ) )
                        $page_ids[] = $options['partner_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $partner_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    if ( ! empty( $options['partner_content_post_' . $i] ) )
                        $post_ids[] = $options['partner_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $partner_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id() ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// partner section content details.
add_filter( 'house_state_pro_filter_partner_section_details', 'house_state_pro_get_partner_section_details' );


if ( ! function_exists( 'house_state_pro_render_partner_section' ) ) :
  /**
   * Start partner section
   *
   * @return string partner content
   * @since House State Pro 1.0.0
   *
   */
   function house_state_pro_render_partner_section( $content_details = array() ) {
        $options = house_state_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="partners-section" class="relative page-section">
            <div class="wrapper">
                <div class="section-content col-6 clear">
                    <?php foreach ($content_details as $content): ?>                   
                        <article><a href="<?php echo esc_url( $content['url'] ) ?>"><img src="<?php echo esc_url( $content['image'] ) ?>" alt="<?php echo esc_attr( $content['title'] ) ?>"></a></article>
                    <?php endforeach ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #partners-section -->       
    <?php
    }    
endif;

function house_state_pro_partner_style( ) {
    $options = house_state_pro_get_theme_options();
?>

    <style type="text/css"> 

        <?php if ( !empty( $options['style_partner_background'] ) ): ?>
           #partners-section{
                background: url('<?php echo esc_url( $options['style_partner_background'] ); ?>');
           }
       <?php endif ?>

       <?php if ( !empty( $options['style_partner_overlay_color'] ) ): ?>
           #partners-section .overlay{
                background-color: <?php echo esc_attr( $options['style_partner_overlay_color'] ); ?>;
           }
       <?php endif ?>

       <?php if ( !empty( $options['style_partner_background_color'] ) ): ?>
           #partners-section{
                background-color: <?php echo esc_attr( $options['style_partner_background_color'] ); ?>;
           }
       <?php endif ?>

       <?php if ( !empty( $options['style_partner_overlay_value'] ) ): ?>
           #partners-section .overlay{
                opacity: 0.<?php echo esc_attr( $options['style_partner_overlay_value'] ); ?>;
           }
       <?php endif ?>

    

    </style>
        
<?php 
}

add_action( 'wp_head', 'house_state_pro_partner_style' );
